[Libreoffice-commits] core.git: comphelper/source

Stephan Bergmann (via logerrit) logerrit at kemper.freedesktop.org
Fri Jun 14 06:17:18 UTC 2019


 comphelper/source/misc/threadpool.cxx |   10 +++++++---
 1 file changed, 7 insertions(+), 3 deletions(-)

New commits:
commit d563059b5177f9640e1ca6a36709f1b2c5a6b363
Author:     Stephan Bergmann <sbergman at redhat.com>
AuthorDate: Fri Jun 14 00:01:38 2019 +0200
Commit:     Stephan Bergmann <sbergman at redhat.com>
CommitDate: Fri Jun 14 08:16:17 2019 +0200

    Extend debug-mode timeout
    
    `--convert-to pdf xls/fdo37212-1.xls`, with xls/fdo37212-1.xls as obtained by
    bin/get-bugzilla-attachments-by-mimetype (i.e., the attachment at
    <https://bugs.documentfoundation.org/show_bug.cgi?id=37212#c0>) needs a timeout
    of more than 5 min for my plain --enable-dbgutil build and a timeout of more
    than 10 min for my ASan+UBSan --enable-dbgutil build.
    
    Change-Id: Ia20140049a2f95c4ac006860599e07687cc594eb
    Reviewed-on: https://gerrit.libreoffice.org/73997
    Tested-by: Jenkins
    Reviewed-by: Stephan Bergmann <sbergman at redhat.com>

diff --git a/comphelper/source/misc/threadpool.cxx b/comphelper/source/misc/threadpool.cxx
index 68ff089d270d..e1b256736cfe 100644
--- a/comphelper/source/misc/threadpool.cxx
+++ b/comphelper/source/misc/threadpool.cxx
@@ -10,6 +10,7 @@
 #include <comphelper/threadpool.hxx>
 
 #include <com/sun/star/uno/Exception.hpp>
+#include <config_options.h>
 #include <sal/config.h>
 #include <sal/log.hxx>
 #include <rtl/instance.hxx>
@@ -351,10 +352,13 @@ void ThreadTaskTag::waitUntilDone()
     while( mnTasksWorking > 0 )
     {
 #if defined DBG_UTIL && !defined NDEBUG
         // 3 minute timeout in debug mode so our tests fail sooner rather than later,
         // unless the code is debugged in valgrind or gdb, in which case the threads
         // should not time out in the middle of a debugging session
-        int maxTimeout = 3 * 60;
+        int maxTimeout = 10 * 60;
+#if !ENABLE_RUNTIME_OPTIMIZATIONS
+        maxTimeout = 30 * 60;
+#endif
 #if defined HAVE_VALGRIND_HEADERS
         if( RUNNING_ON_VALGRIND )
             maxTimeout = 30 * 60;
@@ -351,10 +352,13 @@ void ThreadTaskTag::waitUntilDone()
     {
 #if defined DBG_UTIL && !defined NDEBUG
-        // 3 minute timeout in debug mode so our tests fail sooner rather than later,
-        // unless the code is debugged in valgrind or gdb, in which case the threads
+        // 10 minute timeout in debug mode, unless the code is built with
+        // sanitizers or debugged in valgrind or gdb, in which case the threads
         // should not time out in the middle of a debugging session


More information about the Libreoffice-commits mailing list